from testing.batch import batches

def test_batch_on_lists():
    assert list(batches([1, 2, 3, 4, 5, 6], 1)) == [
        [1], [2], [3], [4], [5], [6]
    ]
    assert list(batches([1, 2, 3, 4, 5, 6], 2)) == [
        [1, 2], [3, 4], [5, 6]
    ]
    assert list(batches([1, 2, 3, 4, 5, 6], 3)) == [
        [1, 2, 3], [4, 5, 6]
    ]
    assert list(batches([1, 2, 3, 4, 5, 6], 4)) == [
        [1, 2, 3, 4], [5, 6]
    ]

def test_batch_with_loop():
    iterable = [1, 2, 3, 4, 5, 6]
    samples = {
        # even batches
        1: [[1], [2], [3], [4], [5], [6]],
        2: [[1, 2], [3, 4], [5, 6]],
        3: [[1, 2, 3], [4, 5, 6]],
        # batches with rest
        4: [[1, 2, 3, 4], [5, 6]]
    }
    for batch_size, expected in samples.items():
        assert list(batches(iterable, batch_size)) == expected

import pytest
@pytest.mark.parametrize(
    "batch_size, expected", [
        # even batches
        [1, [[1], [2], [3], [4], [5], [6]]],
        [2, [[1, 2], [3, 4], [5, 6]]],
        [3, [[1, 2, 3], [4, 5, 6]]],
        # batches with rest
        [4, [[1, 2, 3, 4], [5, 6]]]
    ]
)
def test_batch_parametrized(batch_size, expected):
    iterable = [1, 2, 3, 4, 5, 6]
    assert list(batches(iterable, batch_size)) == expected

@pytest.fixture
def dependency():
    return [1, 2, 3, 4, 5, 6]


@pytest.mark.slow
def test_slow():
    import time
    time.sleep(2.0)

@pytest.mark.skipif()
def test_batch_order_dependency(dependency):
    batch_size = 2
    output = list(batches(dependency, batch_size))
    assert list(chain.from_iterable(output)) == list(dependency)

    
from itertools import chain
    
def test_batch_order():
    iterable = range(100)
    batch_size = 2

    output = list(batches(iterable, batch_size))

    assert list(chain.from_iterable(output)) == list(iterable)

def test_batch_sizes():
    iterable = range(100)
    batch_size = 2

    output = list(batches(iterable, batch_size))

    for batch in output[:-1]:
        assert len(batch) == batch_size
    assert len(output[-1]) <= batch_size
